@@ -1,5 +1,4 @@
 import string
-from gtk import TRUE, FALSE
 from TagObject import TagObject
 
 TAG_NAME = "ref"
@@ -21,10 +20,13 @@ class RefObject(TagObject):
     self.addAttribute("ref", attr)
 
   def isRefObject(self):
-    return TRUE
+    return True
 
   def getName(self):
     try:
       return self.attr_hash["ref"]
     except KeyError, e:
       return ""
+
+  def isDenyAll(self):
+    return self.obj_ptr.isDenyAll()
